package com.ruoyi.system.service.review;

import com.ruoyi.system.domain.review.ReviewComments;

import java.util.List;


/**
 * 业务审核意见Service接口
 * 
 * @author boman
 * @date 2024-04-24
 */
public interface IReviewCommentsService 
{
    /**
     * 查询业务审核意见
     * 
     * @param reviewCommentsId 业务审核意见主键
     * @return 业务审核意见
     */
    public ReviewComments selectReviewCommentsByReviewCommentsId(Long reviewCommentsId);

    /**
     * 查询业务审核意见列表
     * 
     * @param reviewComments 业务审核意见
     * @return 业务审核意见集合
     */
    public List<ReviewComments> selectReviewCommentsList(ReviewComments reviewComments);

    /**
     * 新增业务审核意见
     * 
     * @param reviewComments 业务审核意见
     * @return 结果
     */
    public int insertReviewComments(ReviewComments reviewComments);

    /**
     * 修改业务审核意见
     * 
     * @param reviewComments 业务审核意见
     * @return 结果
     */
    public int updateReviewComments(ReviewComments reviewComments);

    /**
     * 批量删除业务审核意见
     * 
     * @param reviewCommentsIds 需要删除的业务审核意见主键集合
     * @return 结果
     */
    public int deleteReviewCommentsByReviewCommentsIds(Long[] reviewCommentsIds);

    /**
     * 删除业务审核意见信息
     * 
     * @param reviewCommentsId 业务审核意见主键
     * @return 结果
     */
    public int deleteReviewCommentsByReviewCommentsId(Long reviewCommentsId);
}
